"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeHRISClient
from MergeHRISClient.model.deduction import Deduction
from MergeHRISClient.api_client import ApiClient


class TestDeduction(unittest.TestCase):
    """Deduction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeduction(self):
        """Test Deduction"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Deduction()  # noqa: E501

        """
        No test json responses were defined for Deduction
        """
        raw_json = None

        if raw_json is None:
            return

        response_mock = MagicMock()
        response_mock.data = raw_json

        deserialized = ApiClient().deserialize(response_mock, (Deduction,), False)

        assert deserialized is not None



if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from MergeHRISClient.api_client import ApiClient

# import Configuration
from MergeHRISClient.configuration import Configuration

# import exceptions
from MergeHRISClient.exceptions import OpenApiException
from MergeHRISClient.exceptions import ApiAttributeError
from MergeHRISClient.exceptions import ApiTypeError
from MergeHRISClient.exceptions import ApiValueError
from MergeHRISClient.exceptions import ApiKeyError
from MergeHRISClient.exceptions import ApiException



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from MergeHRISClient.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from MergeHRISClient.model.account_details import AccountDetails
from MergeHRISClient.model.account_details_and_actions import AccountDetailsAndActions
from MergeHRISClient.model.account_details_and_actions_integration import AccountDetailsAndActionsIntegration
from MergeHRISClient.model.account_details_and_actions_status_enum import AccountDetailsAndActionsStatusEnum
from MergeHRISClient.model.account_integration import AccountIntegration
from MergeHRISClient.model.account_token import AccountToken
from MergeHRISClient.model.account_type_enum import AccountTypeEnum
from MergeHRISClient.model.available_actions import AvailableActions
from MergeHRISClient.model.bank_info import BankInfo
from MergeHRISClient.model.benefit import Benefit
from MergeHRISClient.model.benefit_plan_type_enum import BenefitPlanTypeEnum
from MergeHRISClient.model.categories_enum import CategoriesEnum
from MergeHRISClient.model.category_enum import CategoryEnum
from MergeHRISClient.model.company import Company
from MergeHRISClient.model.country_enum import CountryEnum
from MergeHRISClient.model.data_passthrough_request import DataPassthroughRequest
from MergeHRISClient.model.deduction import Deduction
from MergeHRISClient.model.earning import Earning
from MergeHRISClient.model.employee import Employee
from MergeHRISClient.model.employee_payroll_run import EmployeePayrollRun
from MergeHRISClient.model.employment import Employment
from MergeHRISClient.model.employment_status_enum import EmploymentStatusEnum
from MergeHRISClient.model.employment_type_enum import EmploymentTypeEnum
from MergeHRISClient.model.end_user_details_request import EndUserDetailsRequest
from MergeHRISClient.model.error_validation_problem import ErrorValidationProblem
from MergeHRISClient.model.ethnicity_enum import EthnicityEnum
from MergeHRISClient.model.flsa_status_enum import FlsaStatusEnum
from MergeHRISClient.model.gender_enum import GenderEnum
from MergeHRISClient.model.generate_remote_key_request import GenerateRemoteKeyRequest
from MergeHRISClient.model.issue import Issue
from MergeHRISClient.model.issue_status_enum import IssueStatusEnum
from MergeHRISClient.model.link_token import LinkToken
from MergeHRISClient.model.location import Location
from MergeHRISClient.model.marital_status_enum import MaritalStatusEnum
from MergeHRISClient.model.method_enum import MethodEnum
from MergeHRISClient.model.model_operation import ModelOperation
from MergeHRISClient.model.paginated_account_details_and_actions_list import PaginatedAccountDetailsAndActionsList
from MergeHRISClient.model.paginated_bank_info_list import PaginatedBankInfoList
from MergeHRISClient.model.paginated_benefit_list import PaginatedBenefitList
from MergeHRISClient.model.paginated_company_list import PaginatedCompanyList
from MergeHRISClient.model.paginated_deduction_list import PaginatedDeductionList
from MergeHRISClient.model.paginated_employee_list import PaginatedEmployeeList
from MergeHRISClient.model.paginated_employee_payroll_run_list import PaginatedEmployeePayrollRunList
from MergeHRISClient.model.paginated_employment_list import PaginatedEmploymentList
from MergeHRISClient.model.paginated_issue_list import PaginatedIssueList
from MergeHRISClient.model.paginated_location_list import PaginatedLocationList
from MergeHRISClient.model.paginated_pay_group_list import PaginatedPayGroupList
from MergeHRISClient.model.paginated_payroll_run_list import PaginatedPayrollRunList
from MergeHRISClient.model.paginated_sync_status_list import PaginatedSyncStatusList
from MergeHRISClient.model.paginated_team_list import PaginatedTeamList
from MergeHRISClient.model.paginated_time_off_balance_list import PaginatedTimeOffBalanceList
from MergeHRISClient.model.paginated_time_off_list import PaginatedTimeOffList
from MergeHRISClient.model.pay_currency_enum import PayCurrencyEnum
from MergeHRISClient.model.pay_frequency_enum import PayFrequencyEnum
from MergeHRISClient.model.pay_group import PayGroup
from MergeHRISClient.model.pay_period_enum import PayPeriodEnum
from MergeHRISClient.model.payroll_run import PayrollRun
from MergeHRISClient.model.policy_type_enum import PolicyTypeEnum
from MergeHRISClient.model.remote_data import RemoteData
from MergeHRISClient.model.remote_data_request import RemoteDataRequest
from MergeHRISClient.model.remote_key import RemoteKey
from MergeHRISClient.model.remote_key_for_regeneration_request import RemoteKeyForRegenerationRequest
from MergeHRISClient.model.remote_response import RemoteResponse
from MergeHRISClient.model.request_format_enum import RequestFormatEnum
from MergeHRISClient.model.request_type_enum import RequestTypeEnum
from MergeHRISClient.model.run_state_enum import RunStateEnum
from MergeHRISClient.model.run_type_enum import RunTypeEnum
from MergeHRISClient.model.sync_status import SyncStatus
from MergeHRISClient.model.sync_status_status_enum import SyncStatusStatusEnum
from MergeHRISClient.model.tax import Tax
from MergeHRISClient.model.team import Team
from MergeHRISClient.model.time_off import TimeOff
from MergeHRISClient.model.time_off_balance import TimeOffBalance
from MergeHRISClient.model.time_off_endpoint_request import TimeOffEndpointRequest
from MergeHRISClient.model.time_off_request import TimeOffRequest
from MergeHRISClient.model.time_off_response import TimeOffResponse
from MergeHRISClient.model.time_off_status_enum import TimeOffStatusEnum
from MergeHRISClient.model.type_enum import TypeEnum
from MergeHRISClient.model.units_enum import UnitsEnum
from MergeHRISClient.model.validation_problem_source import ValidationProblemSource
from MergeHRISClient.model.warning_validation_problem import WarningValidationProblem



"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from MergeHRISClient.api_client import ApiClient, Endpoint as _Endpoint
from MergeHRISClient.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from MergeHRISClient.model.company import Company
from MergeHRISClient.model.paginated_company_list import PaginatedCompanyList


class CompaniesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __companies_list(
            self,
            x_account_token,
            **kwargs
        ):
            """companies_list  # noqa: E501

            Returns a list of `Company` objects.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.companies_list(x_account_token, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.

            Keyword Args:
                created_after (datetime): If provided, will only return objects created after this datetime.. [optional]
                created_before (datetime): If provided, will only return objects created before this datetime.. [optional]
                cursor (str): The pagination cursor value.. [optional]
                include_deleted_data (bool): Whether to include data that was deleted in the third-party service.. [optional]
                include_remote_data (bool): Whether to include the original data Merge fetched from the third-party to produce these models.. [optional]
                modified_after (datetime): If provided, will only return objects modified after this datetime.. [optional]
                modified_before (datetime): If provided, will only return objects modified before this datetime.. [optional]
                page_size (int): Number of results to return per page.. [optional]
                remote_id (str, none_type): The API provider's ID for the given object.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PaginatedCompanyList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            return self.call_with_http_info(**kwargs)

        self.companies_list = _Endpoint(
            settings={
                'response_type': (PaginatedCompanyList,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/companies',
                'operation_id': 'companies_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                    'created_after',
                    'created_before',
                    'cursor',
                    'include_deleted_data',
                    'include_remote_data',
                    'modified_after',
                    'modified_before',
                    'page_size',
                    'remote_id',
                ],
                'required': [
                    'x_account_token',
                ],
                'nullable': [
                    'remote_id',
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                    'created_after':
                        (datetime,),
                    'created_before':
                        (datetime,),
                    'cursor':
                        (str,),
                    'include_deleted_data':
                        (bool,),
                    'include_remote_data':
                        (bool,),
                    'modified_after':
                        (datetime,),
                    'modified_before':
                        (datetime,),
                    'page_size':
                        (int,),
                    'remote_id':
                        (str, none_type,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                    'created_after': 'created_after',
                    'created_before': 'created_before',
                    'cursor': 'cursor',
                    'include_deleted_data': 'include_deleted_data',
                    'include_remote_data': 'include_remote_data',
                    'modified_after': 'modified_after',
                    'modified_before': 'modified_before',
                    'page_size': 'page_size',
                    'remote_id': 'remote_id',
                },
                'location_map': {
                    'x_account_token': 'header',
                    'created_after': 'query',
                    'created_before': 'query',
                    'cursor': 'query',
                    'include_deleted_data': 'query',
                    'include_remote_data': 'query',
                    'modified_after': 'query',
                    'modified_before': 'query',
                    'page_size': 'query',
                    'remote_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__companies_list
        )

        def __companies_retrieve(
            self,
            x_account_token,
            id,
            **kwargs
        ):
            """companies_retrieve  # noqa: E501

            Returns a `Company` object with the given `id`.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.companies_retrieve(x_account_token, id, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.
                id (str):

            Keyword Args:
                include_remote_data (bool): Whether to include the original data Merge fetched from the third-party to produce these models.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                Company
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            kwargs['id'] = \
                id
            return self.call_with_http_info(**kwargs)

        self.companies_retrieve = _Endpoint(
            settings={
                'response_type': (Company,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/companies/{id}',
                'operation_id': 'companies_retrieve',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                    'id',
                    'include_remote_data',
                ],
                'required': [
                    'x_account_token',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                    'id':
                        (str,),
                    'include_remote_data':
                        (bool,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                    'id': 'id',
                    'include_remote_data': 'include_remote_data',
                },
                'location_map': {
                    'x_account_token': 'header',
                    'id': 'path',
                    'include_remote_data': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__companies_retrieve
        )



"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import MergeHRISClient
from MergeHRISClient.model.validation_problem_source import ValidationProblemSource


class TestValidationProblemSource(unittest.TestCase):
    """ValidationProblemSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testValidationProblemSource(self):
        """Test ValidationProblemSource"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ValidationProblemSource()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeHRISClient
from MergeHRISClient.model.remote_data import RemoteData
globals()['RemoteData'] = RemoteData
from MergeHRISClient.model.payroll_run import PayrollRun
from MergeHRISClient.api_client import ApiClient


class TestPayrollRun(unittest.TestCase):
    """PayrollRun unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPayrollRun(self):
        """Test PayrollRun"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PayrollRun()  # noqa: E501

        """
        No test json responses were defined for PayrollRun
        """
        raw_json = None

        if raw_json is None:
            return

        response_mock = MagicMock()
        response_mock.data = raw_json

        deserialized = ApiClient().deserialize(response_mock, (PayrollRun,), False)

        assert deserialized is not None



if __name__ == '__main__':
    unittest.main()



"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeHRISClient
from MergeHRISClient.model.sync_status import SyncStatus
from MergeHRISClient.api_client import ApiClient


class TestSyncStatus(unittest.TestCase):
    """SyncStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSyncStatus(self):
        """Test SyncStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SyncStatus()  # noqa: E501

        raw_json = """
            {"model_name": "Candidate", "model_id": "ats.Candidate", "last_sync_start": "2021-03-30T19:44:18.695973Z", "next_sync_start": "2021-03-30T20:44:18.662942Z", "status": "SYNCING", "is_initial_sync": true}
        """

        if raw_json is None:
            return

        response_mock = MagicMock()
        response_mock.data = raw_json

        deserialized = ApiClient().deserialize(response_mock, (SyncStatus,), False)

        assert deserialized is not None

        assert deserialized.model_name is not None
        assert deserialized.model_id is not None
        assert deserialized.last_sync_start is not None
        assert deserialized.next_sync_start is not None
        assert deserialized.status is not None
        assert deserialized.is_initial_sync is not None


if __name__ == '__main__':
    unittest.main()



"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeHRISClient
from MergeHRISClient.model.pay_frequency_enum import PayFrequencyEnum
from MergeHRISClient.api_client import ApiClient


class TestPayFrequencyEnum(unittest.TestCase):
    """PayFrequencyEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPayFrequencyEnum(self):
        """Test PayFrequencyEnum"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PayFrequencyEnum()  # noqa: E501

        # no tests for enums
        pass

if __name__ == '__main__':
    unittest.main()



"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeHRISClient
from MergeHRISClient.model.account_details_and_actions_integration import AccountDetailsAndActionsIntegration
globals()['AccountDetailsAndActionsIntegration'] = AccountDetailsAndActionsIntegration
from MergeHRISClient.model.account_details_and_actions import AccountDetailsAndActions
from MergeHRISClient.api_client import ApiClient


class TestAccountDetailsAndActions(unittest.TestCase):
    """AccountDetailsAndActions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccountDetailsAndActions(self):
        """Test AccountDetailsAndActions"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AccountDetailsAndActions()  # noqa: E501

        raw_json = """
            {"id": "e59b1821-f85c-4e28-a6b3-1804156f3563", "category": "hris", "status": "COMPLETE", "status_detail": null, "end_user_origin_id": "3ac95cde-6c7f-4eef-afec-be710b42308d", "end_user_organization_name": "Foo Bar, LLC", "end_user_email_address": "hradmin@foobar.dev", "integration": {"name": "SAP SuccessFactors", "categories": ["hris", "ats"], "image": "https://cdn.merge.dev/SuccessFactors_Logo.png", "square_image": "https://cdn.merge.dev/SuccessFactors_Square_Logo.jpg", "color": "#F6A704", "slug": "sap-successfactors", "passthrough_available": true, "available_model_operations": [{"model_name": "Candidate", "available_operations": ["FETCH", "CREATE"], "required_post_parameters": ["remote_user_id"], "supported_fields": ["first_name", "last_name", "company", "title"]}]}}
        """

        if raw_json is None:
            return

        response_mock = MagicMock()
        response_mock.data = raw_json

        deserialized = ApiClient().deserialize(response_mock, (AccountDetailsAndActions,), False)

        assert deserialized is not None

        assert deserialized.id is not None
        assert deserialized.status is not None
        assert deserialized.end_user_organization_name is not None
        assert deserialized.end_user_email_address is not None


if __name__ == '__main__':
    unittest.main()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.account_details_api import AccountDetailsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from MergeHRISClient.api.account_details_api import AccountDetailsApi
from MergeHRISClient.api.account_token_api import AccountTokenApi
from MergeHRISClient.api.available_actions_api import AvailableActionsApi
from MergeHRISClient.api.bank_info_api import BankInfoApi
from MergeHRISClient.api.benefits_api import BenefitsApi
from MergeHRISClient.api.companies_api import CompaniesApi
from MergeHRISClient.api.deductions_api import DeductionsApi
from MergeHRISClient.api.delete_account_api import DeleteAccountApi
from MergeHRISClient.api.employee_payroll_runs_api import EmployeePayrollRunsApi
from MergeHRISClient.api.employees_api import EmployeesApi
from MergeHRISClient.api.employments_api import EmploymentsApi
from MergeHRISClient.api.generate_key_api import GenerateKeyApi
from MergeHRISClient.api.issues_api import IssuesApi
from MergeHRISClient.api.link_token_api import LinkTokenApi
from MergeHRISClient.api.linked_accounts_api import LinkedAccountsApi
from MergeHRISClient.api.locations_api import LocationsApi
from MergeHRISClient.api.passthrough_api import PassthroughApi
from MergeHRISClient.api.payroll_runs_api import PayrollRunsApi
from MergeHRISClient.api.regenerate_key_api import RegenerateKeyApi
from MergeHRISClient.api.sync_status_api import SyncStatusApi
from MergeHRISClient.api.teams_api import TeamsApi
from MergeHRISClient.api.time_off_api import TimeOffApi
from MergeHRISClient.api.time_off_balance_api import TimeOffBalanceApi



"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import unittest

import MergeHRISClient
from MergeHRISClient.api.regenerate_key_api import RegenerateKeyApi  # noqa: E501


class TestRegenerateKeyApi(unittest.TestCase):
    """RegenerateKeyApi unit test stubs"""

    def setUp(self):
        self.api = RegenerateKeyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_regenerate_key_create(self):
        """Test case for regenerate_key_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
